@@ -17,6 +17,12 @@ import subprocess
 
 from fire import Fire
 
+from gtts import gTTS
+from pydub import AudioSegment
+from pydub.playback import play
+
+import re
+
 
 class ScreenTool:
     servlist=[]
@@ -65,8 +71,30 @@ class NotifyClass(object):
         self.message = message
 
 
-    def audio(self):
+    def audio(self, lang="cs"):
+        """
+Use google etxt to speech, not too frequently. Creates an mp3 in /tmp and reads it
+        """
         #print("@"+self.audio.__name__, end='')
+        t = re.compile("[a-zA-Z0-9.,_-]")
+        #unsafe = "abc∂éåß®∆˚˙©¬ñ√ƒµ©∆∫ø"
+        unsafe=self.message
+        safe = [ch for ch in unsafe if t.match(ch)]
+        safe = "".join(safe)
+
+        outfile="/tmp/msg_"+safe+".mp3"
+        if not os.path.isfile(outfile):
+            print("D... contacting google...")
+            tts=gTTS( self.message , lang=lang)
+            tts.save(outfile)
+        else:
+            print("D... taking sound from /tmp/"+outfile)
+
+        # read it
+        path_to_file = outfile
+        song = AudioSegment.from_mp3(path_to_file)
+        play(song)
+
         return self.message
 
     def dbus(self):
@@ -118,19 +146,13 @@ def issueall(message):
     """
     q = Queue(6)   # how does this work?
 
-    #q.put( NotifyClass('audio','Using google talk') )
+    q.put( NotifyClass('audio',message) )
     #q.put( NotifyClass('dbus' ,'notify-send way - works with gtk') )
     q.put( NotifyClass('dbus' ,   message  ) )
     q.put( NotifyClass('hat'  , 'Init sense hat and display') )
     #q.put( NotifyClass('web'  , 'connect to webpy.py') )
     q.put( NotifyClass('term' , message) )
 
-    #for i in range(5):
-    #    if q.full(): break
-    ###############
-    # MAIN PART- accept and queue messages
-    ###############
-
     #================== RPIHAT PART
     #s=ScreenTool()
     #s.run_screen("sleeptest","sleep 10") # this can contain rpihat...
@@ -140,6 +162,37 @@ def issueall(message):
         #print("   ", res)
 
 
+def issue_sound(message):
+    """Issues message to all destinations defined in this function
+    """
+    q = Queue(6)   # how does this work?
+
+    q.put( NotifyClass('audio',message) )
+    #q.put( NotifyClass('dbus' ,'notify-send way - works with gtk') )
+    #q.put( NotifyClass('dbus' ,   message  ) )
+    #q.put( NotifyClass('hat'  , 'Init sense hat and display') )
+    #q.put( NotifyClass('web'  , 'connect to webpy.py') )
+    #q.put( NotifyClass('term' , message) )
+
+    while not q.empty():
+        res=q.get().do()
+
+def issue_dbus(message):
+    """Issues message to all destinations defined in this function
+    """
+    q = Queue(6)   # how does this work?
+
+    #q.put( NotifyClass('audio',message) )
+    #q.put( NotifyClass('dbus' ,'notify-send way - works with gtk') )
+    q.put( NotifyClass('dbus' ,   message  ) )
+    #q.put( NotifyClass('hat'  , 'Init sense hat and display') )
+    #q.put( NotifyClass('web'  , 'connect to webpy.py') )
+    #q.put( NotifyClass('term' , message) )
+
+    while not q.empty():
+        res=q.get().do()
+
+
 #============================================================
 #============================================================
 #============================================================
@@ -147,7 +200,9 @@ def issueall(message):
 #============================================================
 
 if __name__=="__main__":
-    Fire( issueall )
+    Fire( {"a":issueall,
+           "s":issue_sound,
+           "b":issue_dbus})
 
 
 
